@@ -3,13 +3,13 @@ package Padre::Plugin::CSS;
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use base 'Padre::Plugin';
 use Wx ':everything';
 
 sub padre_interfaces {
-	'Padre::Plugin'   => 0.23,
+	'Padre::Plugin'   => 0.26,
 	'Padre::Document' => 0.21,
 }
 
@@ -18,20 +18,23 @@ sub registered_documents {
 }
 
 sub menu_plugins_simple {
-	'CSS' => [
-	    'CSS Minifier',   \&css_minifier,
-		'Validate CSS',   \&validate_css,
-	];
+    my $self = shift;
+    
+	return ('CSS' => [
+	    'CSS Minifier',   sub { $self->css_minifier },
+		'Validate CSS',   sub { $self->validate_css },
+	]);
 }
 
 sub validate_css {
 	my ( $self ) = @_;
+	my $main = $self->main;
 	
-	my $doc  = $self->current->document;
+	my $doc  = $main->current->document;
 	my $code = $doc->text_get;
 	
 	unless ( $code and length($code) ) {
-		Wx::MessageBox( 'No Code', 'Error', Wx::wxOK | Wx::wxCENTRE, $self );
+		Wx::MessageBox( 'No Code', 'Error', Wx::wxOK | Wx::wxCENTRE, $main );
 	}
 	
 	require WebService::Validator::CSS::W3C;
@@ -40,7 +43,7 @@ sub validate_css {
 
 	if ($ok) {
 		if ( $val->is_valid ) {
-			_output( $self, "CSS is valid\n" );
+			$self->_output( "CSS is valid\n" );
 		} else {
 			my $error_text = "CSS is not valid\n";
 			$error_text .= "Errors:\n";
@@ -50,27 +53,30 @@ sub validate_css {
 				$message =~ s/(^\s+|\s+$)//isg;
 				$error_text .= " * $message ($err->{context}) at line $err->{line}\n";
 			}
-			_output( $self, $error_text );
+			$self->_output( $error_text );
 		}
 	} else {
 		my $error_text = sprintf("Failed to validate the code\n");
-        _output( $self, $error_text );
+        $self->_output( $error_text );
 	}
 }
 
 sub _output {
 	my ( $self, $text ) = @_;
+	my $main = $self->main;
 	
-	$self->show_output;
-	$self->{gui}->{output_panel}->clear;
-	$self->{gui}->{output_panel}->AppendText($text);
+	$main->show_output(1);
+	$main->output->clear;
+	$main->output->AppendText($text);
 }
 
 sub css_minifier {
-	my ( $win) = @_;
+	my ( $self ) = @_;
+	my $main = $self->main;
 
-	my $src = $win->current->text;
-	my $doc = $win->current->document;
+	my $src = $main->current->text;
+	my $doc = $main->current->document;
+	return unless $doc;
 	my $code = $src ? $src : $doc->text_get;
 	return unless ( defined $code and length($code) );
 
@@ -80,7 +86,7 @@ sub css_minifier {
 	my $css = minify( $code );
     
     if ( $src ) {
-		my $editor = $win->current->editor;
+		my $editor = $main->current->editor;
 	    $editor->ReplaceSelection( $css );
 	} else {
 		$doc->text_set( $css );
